"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = require("express");
const graphql_tools_1 = require("graphql-tools");
const core_1 = require("@module-stack/core");
const core_server_1 = require("@module-stack/core-server");
const typeDefs1 = `
    type Query {
        hello(name: String): String
    }
`;
const typeDefs2 = `
    type Query {
        random: Float
    }
`;
const resolvers1 = {
    Query: {
        hello: (root, { name }) => `Hello, ${name || 'World'}!`,
    }
};
const resolvers2 = {
    Query: {
        random: () => Math.random(),
    }
};
const router1 = express_1.Router();
router1.get('/__test', (req, res) => res.json({ ok: true }));
const router2 = express_1.Router();
router2.get('/__test__', (req, res) => res.json({ ok: true, math: Math.random() }));
const schema1 = graphql_tools_1.makeExecutableSchema({ resolvers: resolvers1, typeDefs: typeDefs1 });
const schema2 = graphql_tools_1.makeExecutableSchema({ resolvers: resolvers2, typeDefs: typeDefs2 });
const base = core_1.feature({
    schema: schema1,
    router: router1,
    options: { playground: '/playground' },
});
const random = core_1.feature({ schema: schema2, router: router2 });
const validate = async (req) => true;
const application = core_1.feature(base, random);
exports.module = core_1.composed(application, core_server_1.SchemaGraphqlFeature);
